==> cxf-services-xkms-common-3.0.1-sources.jar: org/apache/cxf/xkms/model/xkms/ResponseMechanismEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ResponseMechanismEnum.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ResponseMechanismEnum">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI">
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Pending"/>
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Represent"/>
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#RequestSignatureValue"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ResponseMechanismEnum")
@XmlEnum
public enum ResponseMechanismEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Pending")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PENDING("http://www.w3.org/2002/03/xkms#Pending"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Represent")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REPRESENT("http://www.w3.org/2002/03/xkms#Represent"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#RequestSignatureValue")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REQUEST_SIGNATURE_VALUE("http://www.w3.org/2002/03/xkms#RequestSignatureValue");
    private final String value;

    ResponseMechanismEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static ResponseMechanismEnum fromValue(String v) {
        for (ResponseMechanismEnum c: ResponseMechanismEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> cxf-services-xkms-common-3.0.11-sources.jar: org/apache/cxf/xkms/model/xkms/ResponseMechanismEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ResponseMechanismEnum.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ResponseMechanismEnum"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Pending"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Represent"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#RequestSignatureValue"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ResponseMechanismEnum")
@XmlEnum
public enum ResponseMechanismEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Pending")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PENDING("http://www.w3.org/2002/03/xkms#Pending"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Represent")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REPRESENT("http://www.w3.org/2002/03/xkms#Represent"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#RequestSignatureValue")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REQUEST_SIGNATURE_VALUE("http://www.w3.org/2002/03/xkms#RequestSignatureValue");
    private final String value;

    ResponseMechanismEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static ResponseMechanismEnum fromValue(String v) {
        for (ResponseMechanismEnum c: ResponseMechanismEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
